using System;
using System.Collections.Generic;
using System.Text;
using System.Data;
using System.ComponentModel;

namespace CustomerWinCSharp
{
    class Customer : INotifyPropertyChanged
    {

        #region Enums
        public enum EntityStateEnum
        {
            Unchanged,
            Added,
            Deleted,
            Modified,
        }
        #endregion

        #region Properties
        private EntityStateEnum _EntityState;
        public EntityStateEnum EntityState
        {
            get { return _EntityState; }
            private set { _EntityState = value; }
        }
	
        private string _LastName;
        public string LastName
        {
            get { return _LastName;}
            set
            { 
                if (String.IsNullOrEmpty(value))
                {
                    throw new Exception("The Last Name cannot be empty");
                }
                if (value != _LastName)
                {
                    this.DataStateChange(EntityStateEnum.Modified, "LastName");
                }
                _LastName = value;
            }
        }

        private string _FirstName;
        public string FirstName
        {
            get { return _FirstName; }
            set 
            {
                if (value != _FirstName)
                {
                    this.DataStateChange(EntityStateEnum.Modified, "FirstName");
                }
                _FirstName = value;
            }
        }

        private Boolean _InvoiceViaEmail;
        public Boolean InvoiceViaEmail
        {
            get { return _InvoiceViaEmail; }
            set {
                if (value != _InvoiceViaEmail)
                {
                    this.DataStateChange(EntityStateEnum.Modified, "InvoiceViaEmail");

                    if (value == true)
                    {
                        InvoiceViaFAX = false;
                        InvoiceViaPost = false;
                    }
                }
                _InvoiceViaEmail = value; 
            }
        }

        private Boolean _InvoiceViaFAX;
        public Boolean InvoiceViaFAX
        {
            get { return _InvoiceViaFAX; }
            set
            {
                if (value != _InvoiceViaFAX)
                {
                    this.DataStateChange(EntityStateEnum.Modified, "InvoiceViaFAX");

                    if (value == true)
                    {
                        InvoiceViaEmail = false;
                        InvoiceViaPost = false;
                    }
                }
                _InvoiceViaFAX = value;
            }
        }

        private Boolean _InvoiceViaPost;
        public Boolean InvoiceViaPost
        {
            get { return _InvoiceViaPost; }
            set
            {
                if (value != _InvoiceViaPost)
                {
                    this.DataStateChange(EntityStateEnum.Modified, "InvoiceViaPost");

                    if (value == true)
                    {
                        InvoiceViaEmail = false;
                        InvoiceViaFAX = false;
                    }
                }
                _InvoiceViaPost = value;
            }
        }

        private Int32 _CustomerID;
        public Int32 CustomerID
        {
            get { return _CustomerID; }
            set { _CustomerID = value; }
        }
	
	    public Boolean IsDirty
	    {
		    get{ return this.EntityState!=EntityStateEnum.Unchanged;}
        }
#endregion

#region INotifyPropertyChanged Members

        public event System.ComponentModel.PropertyChangedEventHandler PropertyChanged;

#endregion

        private Customer()
        {
            // Don't allow creation of this object directly
        }

        #region  Public Methods

        #region Create
        public static Customer Create(Int32 CustomerID)
        {
            // Create the customer
            Customer oCustomer = new Customer();

            // Retrieve the data for this customer
            DataRow dr =oCustomer.Retrieve(CustomerID);

            // Populate the business object from the data row
            oCustomer.Populate(dr);

            return oCustomer;
        }
#endregion

        #endregion

        #region Private Methods

        #region Populate
        private void Populate(DataRow CustomerDataRow)
        {
            this.LastName = CustomerDataRow["LastName"].ToString();
            this.FirstName = CustomerDataRow["FirstName"].ToString();
            this.CustomerID = Convert.ToInt32(CustomerDataRow["CustomerID"]);
 
            // This could be defined using an Enum
            switch (Convert.ToInt32(CustomerDataRow["InvoiceVia"]))
            {
                case 1:
                    this.InvoiceViaEmail = true;
                    break;
                case 2:
                    this.InvoiceViaFAX = true;
                    break;
                case 3:
                    this.InvoiceViaPost = true;
                    break;
            }
}
        #endregion

        #region Retrieve
        /// <summary>
        /// Retrieves the Customer data using the appropriate mechanism
        /// </summary>
        /// <param name="CustomerID">ID of the customer for which data is
        /// to be retrieved</param>
        /// <returns></returns>
        /// <remarks>In a real application, this would call a data access component,
        /// access a typed dataset or TableAdapter, or call a Web service.</remarks>
        private DataRow Retrieve(Int32 CustomerID)
        {
            DataTable dt = new DataTable();

            // Define the columns
            dt.Columns.Add("CustomerID");
            dt.Columns.Add("LastName");
            dt.Columns.Add("FirstName");
            dt.Columns.Add("InvoiceVia");

            switch (CustomerID)
            {
                case 1:
                dt.Rows.Add(1, "Einstein", "Albert", 1);
                break;

                case 2:
                dt.Rows.Add(2, "Curie", "Marie", 2);
                break;

                case 3:
                dt.Rows.Add(3, "Brahe", "Tycho", 3);
                break;

                case 4:
                dt.Rows.Add(4, "Faraday", "Michael", 4);
                break;
            }

            return dt.Rows[0];
        }
        #endregion

        #region DataStateChange
        private void DataStateChange(EntityStateEnum dataState, string propertyName)
        {
            // Raise the event
            if (PropertyChanged != null && propertyName != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }

            // If the state is deleted, mark it as deleted
            if (dataState == EntityStateEnum.Deleted)
            {
                this.EntityState = dataState;
            }

            if (this.EntityState == EntityStateEnum.Unchanged)
            {
                this.EntityState = dataState;
            }
        }
        #endregion

        #endregion
    }
}
