using System;
using System.Collections.Generic;
using System.Text;
using System.Data;

namespace CustomerWinCSharp
{
/// <summary>
/// Manages the read-only list of customers for display and selection
/// </summary>
/// <remarks>This is an example of "fake" object binding that actually binds
/// to a data table</remarks>
    class CustomerList
    {
       
#region  Properties
    /// <summary>
    /// Full name of the customer
    /// </summary>
    /// <value></value>
    /// <returns>Customer's full name</returns>
    /// <remarks>This is the display member</remarks>
	public string FullName
	{
		get { return "";}
	}
	
    /// <summary>
    /// ID of the customer
    /// </summary>
    /// <value></value>
    /// <returns>Customer ID</returns>
    /// <remarks>This is the value member</remarks>
	public Int32 CustomerID
	{
		get { return 0;}
	}
	
    /// <summary>
    /// DataTable containing the customer list data
    /// </summary>
    /// <value></value>
    /// <returns>Customer DataTable</returns>
    /// <remarks>The list is bound to this DataTable</remarks>
    public DataTable CustomerDataTable
    {
        get { return Retrieve();}
    }
#endregion

#region  Private Methods

#region  Retrieve
    /// <summary>
    /// Retrieves the DataTable using the appropriate mechanism
    /// </summary>
    /// <returns></returns>
    /// <remarks>In a real application, this would call a data access component,
    /// access a typed dataset or TableAdapter, or call a Web service.</remarks>
    private DataTable Retrieve()
    {
        DataTable dt = new DataTable();

        dt.Columns.Add("FullName");
        dt.Columns.Add("CustomerID");

        dt.Rows.Add("Einstein, Albert", 1);
        dt.Rows.Add("Curie, Marie", 2);
        dt.Rows.Add("Brahe, Tycho", 3);
        dt.Rows.Add("Faraday, Michael", 4);

        return dt;
    }
#endregion

#endregion


    }
}
