using System;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel;
using System.Data;

namespace CustomerWinCSharp
{
    /// <summary>
    /// Manages the collection of items purchased by a single customer
    /// </summary>
    /// <remarks></remarks>
    class PurchasedItemCollection : BindingList<PurchasedItem>
    {

#region Public Methods

#region  Create
    /// <summary>
    /// Creates an instance of this collection populated with all items purchased
    /// by the defined customer
    /// </summary>
    /// <param name="CustomerID">ID of the customer</param>
    /// <returns></returns>
    /// <remarks></remarks>
    public static PurchasedItemCollection Create(Int32 CustomerID)
    {
        PurchasedItemCollection oCollection = new PurchasedItemCollection();

        // Perform the appropriate retrieve
        DataTable dt = oCollection.Retrieve(CustomerID);

        // For each row, create an object in the list
        foreach (DataRow dr in dt.Rows)
        {
            PurchasedItem oItem = PurchasedItem.Create(dr);

            oCollection.Add(oItem);
    	 
        }
        return oCollection;
    }
#endregion

#endregion

#region Private Methods

#region Retrieve
    /// <summary>
    /// Retrieves the PurchasedItem data using the appropriate mechanism
    /// </summary>
    /// <param name="CustomerID">ID of the customer for which PurchasedItems
    /// are to be retrieved</param>
    /// <returns></returns>
    /// <remarks>In a real application, this would call a data access component,
    /// access a typed dataset or TableAdapter, or call a Web service.</remarks>
    private DataTable Retrieve(Int32 CustomerID)
    {
        DataTable dt = new DataTable();

        // Define the columns
        dt.Columns.Add("ItemID");
        dt.Columns.Add("ItemName");
        dt.Columns.Add("Description");
        dt.Columns.Add("CustomerID");

       // Test data
        switch (CustomerID)
        {
            case 1:
                dt.Rows.Add(1, "Accelerator", "Linear particle accelerator", 1);
                dt.Rows.Add(2, "Scale", "Standard chemical scale", 1);
                dt.Rows.Add(3, "Telescope", "Night vision telescope", 1);
                dt.Rows.Add(4, "Table", "Periodic table of elements", 1);
                break;

            case 2:
                dt.Rows.Add(2, "Scale", "Standard chemical scale", 2);
                dt.Rows.Add(4, "Table", "Periodic table of elements", 2);
                 break;
       
            case 3:
                dt.Rows.Add(3, "Telescope", "Night vision telescope", 2);
                break;

            case 4:
                dt.Rows.Add(1, "Accelerator", "Linear particle accelerator", 3);
                dt.Rows.Add(2, "Scale", "Standard chemical scale", 3);
                dt.Rows.Add(4, "Table", "Periodic table of elements", 3);
                break;
        }

        return dt;
    }
#endregion

#endregion

    }
}
