''' <summary>
''' Manages a single item purchased by a customer
''' </summary>
''' <remarks></remarks>
Public Class PurchasedItem

#Region " Properties"
    Private _ItemID As Int32
    ''' <summary>
    ''' Primary key of the item
    ''' </summary>
    ''' <value></value>
    ''' <returns>Item ID</returns>
    ''' <remarks></remarks>
    Public Property ItemID() As Int32
        Get
            Return _ItemID
        End Get
        Set(ByVal value As Int32)
            _ItemID = value
        End Set
    End Property

    Private _ItemName As String
    ''' <summary>
    ''' Name of the item
    ''' </summary>
    ''' <value></value>
    ''' <returns>Item name</returns>
    ''' <remarks></remarks>
    Public Property ItemName() As String
        Get
            Return _ItemName
        End Get
        Set(ByVal value As String)
            _ItemName = value
        End Set
    End Property

    Private _Description As String
    ''' <summary>
    ''' Description of the item
    ''' </summary>
    ''' <value></value>
    ''' <returns>Item description</returns>
    ''' <remarks></remarks>
    Public Property Description() As String
        Get
            Return _Description
        End Get
        Set(ByVal value As String)
            _Description = value
        End Set
    End Property

    Private _CustomerID As Int32
    ''' <summary>
    ''' ID of the Customer who purchased this item
    ''' </summary>
    ''' <value></value>
    ''' <returns>Customer ID</returns>
    ''' <remarks></remarks>
    Public Property CustomerID() As Int32
        Get
            Return _CustomerID
        End Get
        Private Set(ByVal value As Int32)
            _CustomerID = value
        End Set
    End Property

    Private _CustomerInstance As Customer
    ''' <summary>
    ''' Instance defining the customer who purchased this item
    ''' </summary>
    ''' <value></value>
    ''' <returns>Customer instance</returns>
    ''' <remarks>This property is read-only</remarks>
    Public ReadOnly Property CustomerInstance() As Customer
        Get
            If _CustomerInstance Is Nothing Then
                _CustomerInstance = Customer.Create(CustomerID)
            End If

            Return _CustomerInstance
        End Get
    End Property

    Public ReadOnly Property CustomerName() As String
        Get
            Return CustomerInstance.LastName
        End Get
    End Property
#End Region

#Region " Public Methods"

#Region " Create"
    ''' <summary>
    ''' Creates an instance of the class
    ''' </summary>
    ''' <param name="dr">DataRow containing the data to populate the instance</param>
    ''' <returns>Fully populated PurchasedItem instance</returns>
    ''' <remarks></remarks>
    Public Shared Function Create(ByVal dr As DataRow) As PurchasedItem
        Dim oItem As New PurchasedItem

        ' Populate the object
        With oItem
            .ItemID = dr.Item("ItemID")
            .ItemName = dr.Item("ItemName").ToString
            .Description = dr.Item("Description").ToString
            .CustomerID = dr.Item("CustomerID")
        End With

        Return oItem
    End Function
#End Region

#End Region

End Class
